
# Slot: in pathway with


holds between two genes or gene products that are part of in the same biological pathway

URI: [biolink:in_pathway_with](https://w3id.org/biolink/vocab/in_pathway_with)


## Domain and Range

[GeneOrGeneProduct](GeneOrGeneProduct.md) &#8594;  <sub>0..\*</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [coexists with](coexists_with.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Related Mappings:** | | SIO:010532 |

